from . import db
import json
from os.path import join
import collections

SERVER_URL = "https://app.dbrhino.com"


class Config(object):
    def __init__(self, *, access_token, server_url=SERVER_URL, databases={}):
        self.access_token = access_token
        self.server_url = server_url
        self.databases = {
            name: db.create(name=name, **conf)
            for name, conf in databases.items()
        }

    @classmethod
    def from_file(cls, filename):
        with open(filename) as f:
            return cls(**json.loads(f.read()))

    def find_database(self, name):
        return self.databases[name]

    @property
    def remote_headers(self):
        return {
            "Content-Type": "application/json",
            "Accept": "application/json",
            "Authorization": "Bearer " + self.access_token,
        }

    def remote_url(self, path):
        return join(self.server_url, path.lstrip("/"))
